require 'spec_helper_acceptance'

ip_server = fact('networking.ip')

describe 'coturn' do
  context 'with defaults' do
    pp = %(
      class { 'coturn' :
        realm => 'coturn.example.org',
      }
    )

    it 'applies without error' do
      apply_manifest(pp, catch_failures: true)
    end
    it 'applies idempotently' do
      apply_manifest(pp, catch_changes: true)
    end

    describe package('coturn') do
      it { is_expected.to be_installed }
    end

    describe service('coturn') do
      it { is_expected.to be_running }
    end

    describe file('/etc/turnserver.conf') do
      it { is_expected.to be_file }
      its(:content) { is_expected.to contain 'listening-port=3478' }
      its(:content) { is_expected.to contain 'realm=coturn.example.org' }
    end

    describe file('/etc/default/coturn') do
      it { is_expected.to be_file }
      its(:content) { is_expected.to match %r{^TURNSERVER_ENABLED=1} }
    end

    describe command('ss -ltn') do
      its(:stdout) { is_expected.to match %r{.*LISTEN[\s\d]*\s127\.0\.0\.1:3478\s.*} }
      its(:stdout) { is_expected.to match %r{.*LISTEN[\s\d]*\s#{ip_server}:3478\s.*} }
    end
  end

  context 'with custom listening port' do
    pp = %(
      class { 'coturn' :
        realm          => 'coturn.example.org',
        listening_port => 88,
      }
    )

    it 'applies without error' do
      apply_manifest(pp, catch_failures: true)
    end
    it 'applies idempotently' do
      apply_manifest(pp, catch_changes: true)
    end

    describe service('coturn') do
      it { is_expected.to be_running }
    end

    describe file('/etc/turnserver.conf') do
      it { is_expected.to be_file }
      its(:content) { is_expected.to contain 'realm=coturn.example.org' }
      its(:content) { is_expected.to contain 'listening-port=88' }
    end

    describe command('ss -ltn') do
      its(:stdout) { is_expected.to match %r{.*LISTEN[\s\d]*\s127\.0\.0\.1:88\s.*} }
      its(:stdout) { is_expected.to match %r{.*LISTEN[\s\d]*\s#{ip_server}:88\s.*} }
    end
  end
end
