require 'spec_helper'

describe 'coturn' do
  on_supported_os.each do |os, os_facts|
    context "on #{os}" do
      let(:facts) { os_facts }
      let(:params) do
        {
          realm: 'coturn.example.org',
        }
      end

      it { is_expected.to compile }
      it { is_expected.to contain_service('coturn') }
      it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{realm=coturn.example.org}) }
      it { is_expected.to contain_file('/etc/turnserver.conf').that_notifies('Service[coturn]') }

      context 'with given listening_ips' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            listening_ips: ['1.2.3.4', '5.6.7.8'],
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{listening-ip=1.2.3.4}) }
        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{listening-ip=5.6.7.8}) }
      end

      context 'with given tls_listening_port' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            tls_listening_port: 88,
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{tls-listening-port=88}) }
      end

      context 'with given cert' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            cert: '/etc/cert/example.com.pem',
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{cert=/etc/cert/example.com.pem}) }
      end

      context 'with given private_key' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            private_key: '/etc/cert/pkey_example.com.pem',
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{pkey=/etc/cert/pkey_example.com.pem}) }
      end

      context 'with dh2066 true' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            dh2066: true,
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{dh2066}) }
      end

      context 'with tlsv1 false' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            tlsv1: false,
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{no-tlsv1}) }
      end

      context 'with tlsv1_1 false' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            tlsv1_1: false,
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{no-tlsv1_1}) }
      end

      context 'with simple_log true' do
        let(:params) do
          {
            realm: 'coturn.example.org',
            simple_log: true,
          }
        end

        it { is_expected.to contain_file('/etc/turnserver.conf').with_content(%r{simple-log}) }
      end
    end
  end
end
